#
# spec file for package bats
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bats
Version:        1.2.0
Release:        lp152.1.1
Summary:        Bash Automated Testing System
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/bats-core/bats-core/
Source:         https://github.com/bats-core/bats-core/archive/v%{version}.tar.gz
BuildRequires:  ncurses-utils
BuildArch:      noarch

%description
Bats is a TAP-compliant (http://testanything.org/) testing framework for Bash.
It provides a simple and repeatable way to verify that the UNIX programs you
write behave as expected.

A Bats test file is a Bash script with special syntax for defining test cases.
Under the hood, each test case is just a function with a description.

Bats is most useful when testing software written in Bash, but you can use it
to test any UNIX program.

%prep
%setup -q -n %{name}-core-%{version}
mv libexec lib

sed -i 's|libexec|lib|g' install.sh ./lib/bats-core/* ./bin/bats
sed -i '1s|#!%{_bindir}/env bash|#!/bin/bash|' ./lib/bats-core/* ./bin/bats

%build

%install
./install.sh %{buildroot}%{_prefix}

%check
./bin/bats test/bats.bats
./bin/bats test/suite.bats

%files
%license LICENSE.md
%doc README.md
%{_bindir}/bats
%{_prefix}/lib/%{name}-core
%{_mandir}/man1/bats.1%{?ext_man}
%{_mandir}/man7/bats.7%{?ext_man}

%changelog
* Wed May 20 2020 Olav Reinert <seroton10@gmail.com>
- update to 1.2.0:
  * Added:
  - docs/CHANGELOG.md and docs/releasing.md (#122)
  - The -f, --filter flag to run only the tests matching a regular expression (#126)
  - Optimize stack trace capture (#138)
  - --jobs n flag to support parallel execution of tests with GNU parallel (#172)
  * Changed:
  - AppVeyor builds are now semver-compliant (#123)
  - Add Bash 5 as test target (#181)
  - Always use upper case signal names to avoid locale dependent err… (#215)
  - Fix for tests reading from stdin (#227)
  - Fix wrong line numbers of errors in bash < 4.4 (#229)
  - Remove preprocessed source after test run (#232)
* Fri Oct 25 2019 Olav Reinert <seroton10@gmail.com>
- Reinstate prematurely removed Group tag
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Jan 22 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.1.0
- drop build-term.patch  package-json.patch
- new upstream, see changes on https://github.com/bats-core/bats-core/releases
* Sat Feb 25 2017 seroton10@gmail.com
- Added build-term.patch: work-around for bnc#1026350
* Tue Feb 24 2015 seroton10@gmail.com
- Fix RPM group
* Sun Feb 22 2015 seroton10@gmail.com
- Spec file improvements:
  * Run tests in %%check section
  * Correct project URL
* Wed Feb 18 2015 seroton10@gmail.com
- Spec file improvements:
  * /usr/bin/tput is optional at runtime
  * Reference to meaning of TAP-compliant
  * Simplify launch of tests
* Mon Feb 16 2015 seroton10@gmail.com
- Initial version: bats 0.4.0
